﻿Public Class MainWindowViewModel
    Inherits ViewModel

    Public Sub New()
        Me._results = ViewModelHelper.
            CreateReadOnlyNotificationDispatcherCollection(Me.model.Results,
                                                           Function(model) New WikipediaItemViewModel(model),
                                                           DispatcherHelper.UIDispatcher)

        ViewModelHelper.BindNotification(Me.model.ApiErrorEventNotificator, Me,
                                         Sub(sender, e)
                                             Me.Messenger.Raise(New InformationMessage(e.Message, "エラー", "ShowInfo"))
                                         End Sub)
    End Sub

    Private model As New Model()

    Private _results As ReadOnlyNotificationDispatcherCollection(Of WikipediaItemViewModel)
    Public ReadOnly Property Results As ReadOnlyNotificationDispatcherCollection(Of WikipediaItemViewModel)
        Get
            Return Me._results
        End Get
    End Property

    Private _SearchText As String

    Public Property SearchText() As String
        Get
            Return _SearchText
        End Get
        Set(ByVal value As String)
            If _SearchText = value Then Return
            _SearchText = value
            RaisePropertyChanged("SearchText")
            Me.SearchCommand.RaiseCanExecuteChanged()
        End Set
    End Property

#Region "SearchCommand"
    Private _SearchCommand As ViewModelCommand

    Public ReadOnly Property SearchCommand() As ViewModelCommand
        Get
            If _SearchCommand Is Nothing Then
                _SearchCommand = New ViewModelCommand(AddressOf Search, AddressOf CanSearch)
            End If
            Return _SearchCommand
        End Get
    End Property

    Private Function CanSearch() As Boolean
        Return Not String.IsNullOrWhiteSpace(Me.SearchText)
    End Function

    Private Sub Search()
        Me.model.Search(Me.SearchText)
    End Sub
#End Region

    Private _SelectedItem As WikipediaItemViewModel

    Public Property SelectedItem() As WikipediaItemViewModel
        Get
            Return _SelectedItem
        End Get
        Set(ByVal value As WikipediaItemViewModel)
            If _SelectedItem Is value Then Return
            _SelectedItem = value
            RaisePropertyChanged("SelectedItem")
            Me.Messenger.Raise(New InteractionMessage("UpdateBrowserView"))
        End Set
    End Property

End Class
